//Face Plate for Graphic Controller to use with Arduino/Rambo Mini Case
//7/29/2017 By: David Bunch
//
FP_Len = 169.3-20+20;   //Length to Extrude FacePlate
FP_Ht = 4;              //Height or Thickness of Face Plate
FP_HoleLen = 87.95;     //Distance Between holes along Length
FP_HoleWid = 65;        //Distance Between holes along Width
FP_Test_Ht = .6;            //Test Height to use for Face Plate Test Print
M3 = 3.6;                   //Size of M3 Bolt Holes

M3Head = 6.0;               //Size of M3 bolt head for countersinking

StopSwitch_X = 84.9+5;      //X offset of Stop Switch Hole
StopSwitch_Y = -4.62+5;     //Y offset of Stop Switch Hole

ControlKnob_X = 117.9+5;    //X offset of Control Knob Hole
ControlKnob_Y = -4.62+5;    //Y offset of Control Knob Hole

SpeakerHole_X = 100.15+5;   //X offset of Center of Speaker Holes
SpeakerHole_Y = -4.62+5;    //Y offset of Center of Speaker Holes

DisplayPart = 4;        //Use either 4 or 8 here
                        //4 = Draw FacePlate Only
                        //8 = FacePlate Test Print
$fn=24;
module LCD_Graphic_Display()
{
    translate([44.45-.3-5.875,-14.12+1.5,-10.9])
    translate([-9,0,0])
    translate([-10.15,0,-9])
    import("Full_Graphic_Smart_Controller_302196.STL",convexity=3);
}
module FacePlate()
{
    difference()
    {
        translate([-9,0,0])
        union()
        {
            translate([0,57,4])
            rotate([0,0,-90])
            rotate([-90,0,0])
            linear_extrude(height = FP_Len, center = false, convexity = 10)polygon(points = 
            [[-28.36,0],[65.17,0],[65.81,0.02],[66.45,0.07],[67.09,0.15],
            [67.72,0.27],[68.35,0.42],[68.97,0.6],[69.58,0.82],[70.17,1.06],
            [70.75,1.34],[71.32,1.65],[74.53,3.5],[75.15,3.98],[75.62,4.6],
            [75.92,5.32],[76.02,6.1],[75.92,6.87],[75.62,7.59],[75.12,8.46],
            [69.3,5.11],[68.33,4.63],[67.3,4.28],[66.24,4.07],[65.15,4],
            [-29.53,4],[-31.28,5.75],[-32.69,4.33]]);
        }
        translate([-5.875 - 10 - 25,1.4,0])
        {
            translate([42.5-.5+5,13.73-.5+5,-1])
            cube([78.45+1,51+1,FP_Ht+2]);
//Drill 6 holes in face plate, 4 holes for brackets & 2 holes for middle side of LCD 
            for (y = [5.23+7,FP_HoleWid+5.23+7])
            {
                for (x = [37.5+5,FP_HoleLen+37.5+5,FP_Len+25-4])
                {
                    echo("x = ", x, "   y = ",y);
                    translate([x,y,-1])
                    cylinder(d=M3,h=FP_Ht+2);
                    if (DisplayPart != 8)
                    {
                        translate([x,y,FP_Ht-2])
                        cylinder(d=M3Head,h=FP_Ht+2);
                        translate([x,y,FP_Ht-3])
                        cylinder(d1=M3,d2=M3Head,h=1.02);
                    }
                }
            }
//Bottom Stop Switch Slot Hole
            translate([StopSwitch_X,StopSwitch_Y,-1])
            cylinder(d=8.63,h=FP_Ht+2,$fn=38);
//Controller knob
            translate([ControlKnob_X,ControlKnob_Y,-1])
            cylinder(d=10,h=FP_Ht+2,$fn=40);
//Small holes for speaker noise to come thru
            for (x = [-3.7,0,3.7])
            {
                translate([SpeakerHole_X+x,SpeakerHole_Y,-1])
                cylinder(d=2.5,h=FP_Ht+2,$fn=72);
            }
            translate([SpeakerHole_X,SpeakerHole_Y,-2])
            cylinder(d=15,h=FP_Ht,$fn=72);          //Inset for speaker to fit inside
        }
    }
    translate([-10-25+5,7,0])
    %LCD_Graphic_Display();
}
if (DisplayPart == 4)
{
    translate([160,0,FP_Ht])
    rotate([0,180,0])
    FacePlate();
} else if (DisplayPart == 8)
{
    difference()
    {
        translate([160,0,FP_Ht])
        rotate([0,180,0])
        FacePlate();
        translate([0,0,FP_Test_Ht])
        cylinder(d=500,h=100);
    }
}